about summary refs log tree commit diff
path: root/nixos/tests/nscd.nix
diff options
context:
space:
mode:
Diffstat (limited to 'nixos/tests/nscd.nix')
-rw-r--r--nixos/tests/nscd.nix5
1 files changed, 3 insertions, 2 deletions
diff --git a/nixos/tests/nscd.nix b/nixos/tests/nscd.nix
index 7bb6d90c3d4e0..23f03b6d82626 100644
--- a/nixos/tests/nscd.nix
+++ b/nixos/tests/nscd.nix
@@ -40,9 +40,10 @@ in
                   "systemd-run --pty --property=Type=oneshot --property=DynamicUser=yes --property=User=iamatest whoami"
               )
 
       # Test resolution of somehost.test with getent', to make sure we go via nscd
       def test_host_lookups():
-          with subtest("host lookups via nscd"):
+          with subtest("host lookups via nscd protocol"):
               # ahosts
               output = machine.succeed("${getent'} ahosts somehost.test")
               assert "192.0.2.1" in output
@@ -40,9 +40,10 @@ in
               )
 
-      # Test resolution of somehost.test with getent', to make sure we go via nscd
+      # Test resolution of somehost.test with getent', to make sure we go via
+      # nscd protocol
       def test_host_lookups():